@@ -1,4 +1,4 @@
-# copyright 2018-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2018-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -63,7 +63,7 @@ class S3Storage(Storage):
         try:
             return self.download(key)
         except Exception as ex:
-            source.critical("can't retrieve S3 object %s: %s", value, ex)
+            source.critical("can't retrieve S3 object %s: %s", key, ex)
             return None
 
     def entity_added(self, entity, attr):
